@@ -67,4 +67,27 @@ DOTENV_FILE_LOCATION = '.env'
 # AWS settings
 AWS_REGION = 'eu-west-1'
 
-# SEc
+# Docker settings
+DOCKERFILE_NAME = 'Dockerfile'
+DOCKERFILE_CONTENT = r"""# Python 3.6 Image without Dependecies
+FROM python:3.7
+
+LABEL maintainer="vijay.vammi@astrazeneca.com"
+
+RUN apt-get update && apt-get install -y --no-install-recommends \
+    git \
+    && rm -rf /var/lib/apt/lists/*
+
+${INSTALL_STYLE}
+
+ENV VIRTUAL_ENV=/opt/venv
+RUN python -m virtualenv --python=/usr/local/bin/python $VIRTUAL_ENV
+ENV PATH="$VIRTUAL_ENV/bin:$PATH"
+
+${COPY_CONTENT}
+WORKDIR /app
+
+${INSTALL_REQUIREMENTS}
+"""
+GIT_ARCHIVE_NAME = 'git_tracked'
+LEN_SHA_FOR_TAG = 8
